<?php

/**
 * Key Captcha
 *
 * @author  Mersane Ltd
 * @license BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.1
 *
 */

/**
 * This function adds the verification to the list of known ones
 *
 * @param $known_verifications
 */
function key_captcha(&$known_verifications)
{
	$known_verifications[] = 'keycaptcha';
	loadLanguage('KeyCaptcha');
}

/**
 * Class Verification_Controls_Keycaptcha
 */
class Verification_Controls_Keycaptcha implements Verification_Controls
{
	/**
	 * @var KeyCAPTCHA_CLASS|string
	 */
	private $kc_o = '';

	/**
	 * Verification_Controls_Keycaptcha constructor.
	 *
	 * @param null|array $verificationOptions
	 */
	public function __construct($verificationOptions = null)
	{
		global $modSettings;

		require_once(SUBSDIR . '/KeyCaptcha.class.php');
		$this->kc_o = new KeyCAPTCHA_CLASS($modSettings['configure_keycaptcha_private_key']);

		if (!empty($verificationOptions))
		{
			$this->_options = $verificationOptions;
		}
	}

	/**
	 * Show the verification if its enabled
	 *
	 * @param bool $isNew
	 * @param bool $force_refresh
	 *
	 * @return bool
	 */
	public function showVerification($isNew, $force_refresh = true)
	{
		global $modSettings;

		if ($modSettings['enable_keycaptcha'] == 1)
		{
			$this->show_captcha = true;
		}

		return $this->show_captcha;
	}

	/**
	 * Done in the main KeyCaptcha Class
	 *
	 * @param bool $refresh
	 *
	 * @return bool
	 */
	public function createTest($refresh = true)
	{
	}

	/**
	 * Return an array that will be used in VerificationControls.template

	 * @return array
	 */
	public function prepareContext()
	{
		global $modSettings;

		// Our template
		loadTemplate('KeyCaptcha');

		// This may not be loaded if other controls were not enabled, we need it
		loadTemplate('VerificationControls');

		if (trim($modSettings['configure_keycaptcha_task']) === '')
		{
			$task = 'Anti-spam: Complete the task';
		}
		else
		{
			$task = $modSettings['configure_keycaptcha_task'];
		}

		return array(
			'template' => 'keycaptcha',
			'values' => array(
				'kcjs' => $this->kc_o->render_js(),
				'task' => $task,
			)
		);
	}

	/**
     * Run the test, return the result
     *
	 * @return bool|string
	 */
	public function doTest()
	{
		if ($this->kc_o->check_result($_REQUEST['capcode']))
		{
			return true;
		}

		return 'error_wrong_keycaptcha';
	}

	/**
	 * Visible form? you bet it is

	 * @return bool
	 */
	public function hasVisibleTemplate()
	{
		return true;
	}

	/**
	 * Settings for the ACP
     *
	 * @return array
	 */
	public function settings()
	{
		$config_vars = array(
			array('title', 'configure_keycaptcha'),
			array('desc', 'configure_keycaptcha_desc'),
			array('check', 'enable_keycaptcha'),
			array('text', 'configure_keycaptcha_private_key'),
			array('text', 'configure_keycaptcha_task'),
		);

		return $config_vars;
	}
}